%CODIFICADOR RPE.
%function[Mc,xm]=rpesel(x)
%Entradas:
%x:excitación residual filtrada.
%Salidas:
%Mc:posición RPE codificada.
%xm:subsecuencia de máxima energía.
function[Mc,xm]=rpesel(x)
for m=1:4
   for i=1:13
      xmp(m,i)=x(m+3*(i-1));
   end
end
for m=1:4
   E(m)=sum(xmp(m,:).^2);
end
[var,Mcaux]=max(E);
Mc=Mcaux-1;
xm=xmp(Mc+1,:);